==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/AssigningSeriesShapeStyleEventArgsBaseDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { AssigningSeriesStyleEventArgsBaseDescription } from "./AssigningSeriesStyleEventArgsBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var AssigningSeriesShapeStyleEventArgsBaseDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(AssigningSeriesShapeStyleEventArgsBaseDescription, _super);
    function AssigningSeriesShapeStyleEventArgsBaseDescription() {
        var _this = _super.call(this) || this;
        _this.aq = 0;
        _this.ao = 0;
        _this.ap = 0;
        return _this;
    }
    AssigningSeriesShapeStyleEventArgsBaseDescription.prototype.get_type = function () {
        return "AssigningSeriesShapeStyleEventArgsBase";
    };
    Object.defineProperty(AssigningSeriesShapeStyleEventArgsBaseDescription.prototype, "strokeThickness", {
        get: function () {
            return this.aq;
        },
        set: function (a) {
            this.aq = a;
            this.e("StrokeThickness");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AssigningSeriesShapeStyleEventArgsBaseDescription.prototype, "radiusX", {
        get: function () {
            return this.ao;
        },
        set: function (a) {
            this.ao = a;
            this.e("RadiusX");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AssigningSeriesShapeStyleEventArgsBaseDescription.prototype, "radiusY", {
        get: function () {
            return this.ap;
        },
        set: function (a) {
            this.ap = a;
            this.e("RadiusY");
        },
        enumerable: true,
        configurable: true
    });
    AssigningSeriesShapeStyleEventArgsBaseDescription.$t = markType(AssigningSeriesShapeStyleEventArgsBaseDescription, 'AssigningSeriesShapeStyleEventArgsBaseDescription', AssigningSeriesStyleEventArgsBaseDescription.$);
    return AssigningSeriesShapeStyleEventArgsBaseDescription;
}(AssigningSeriesStyleEventArgsBaseDescription));
export { AssigningSeriesShapeStyleEventArgsBaseDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/AssigningSeriesShapeStyleEventArgsBaseDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { AssigningSeriesStyleEventArgsBaseDescription } from "./AssigningSeriesStyleEventArgsBaseDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var AssigningSeriesShapeStyleEventArgsBaseDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AssigningSeriesShapeStyleEventArgsBaseDescription, _super);
    function AssigningSeriesShapeStyleEventArgsBaseDescription() {
        var _this = _super.call(this) || this;
        _this.bg = 0;
        _this.bc = null;
        _this.be = 0;
        _this.bf = 0;
        return _this;
    }
    AssigningSeriesShapeStyleEventArgsBaseDescription.prototype.get_type = function () {
        return "AssigningSeriesShapeStyleEventArgsBase";
    };
    Object.defineProperty(AssigningSeriesShapeStyleEventArgsBaseDescription.prototype, "strokeThickness", {
        get: function () {
            return this.bg;
        },
        set: function (a) {
            this.bg = a;
            this.g("StrokeThickness");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(AssigningSeriesShapeStyleEventArgsBaseDescription.prototype, "strokeDashArray", {
        get: function () {
            return this.bc;
        },
        set: function (a) {
            this.bc = a;
            this.g("StrokeDashArray");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(AssigningSeriesShapeStyleEventArgsBaseDescription.prototype, "radiusX", {
        get: function () {
            return this.be;
        },
        set: function (a) {
            this.be = a;
            this.g("RadiusX");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(AssigningSeriesShapeStyleEventArgsBaseDescription.prototype, "radiusY", {
        get: function () {
            return this.bf;
        },
        set: function (a) {
            this.bf = a;
            this.g("RadiusY");
        },
        enumerable: false,
        configurable: true
    });
    AssigningSeriesShapeStyleEventArgsBaseDescription.$t = markType(AssigningSeriesShapeStyleEventArgsBaseDescription, 'AssigningSeriesShapeStyleEventArgsBaseDescription', AssigningSeriesStyleEventArgsBaseDescription.$);
    return AssigningSeriesShapeStyleEventArgsBaseDescription;
}(AssigningSeriesStyleEventArgsBaseDescription));
export { AssigningSeriesShapeStyleEventArgsBaseDescription };
